.. Pasee documentation master file, created by
   sphinx-quickstart on Wed Jul 10 12:04:24 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Pasee's documentation!
=================================

The name "Pasee", inspired from "Kisee" (the IdM), spoken as the
french phrase "Passez !", ``[ˈpɑːsə(ɹ)]``.

Pasee is a simple layer over multiple IdMs, typically a Kisee
and other identity providers like Twitter, Github, …

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   features
   API
   configuration
   contributing
   faq


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
